;******************************************************************************
;* File Name          : I2C_Init.inc
;* Author             : MASSES CHIP
;* Version            : V1.00
;* Date               : 2019/07/01
;******************************************************************************
;
;  I2C  初始化
;
;******************************************************************************
;//宏定义配置字值
;//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
; ; Bit 7 I2CEN: 使能发送
; ; 1 = 使能串行通讯功能
; ; 0 = 屏蔽串行通讯功能
; ; Bit 6 R_W: 发送寄存器空标志
; ; 1 = Master读数据（主机发接收数据命令）
; ; 0 = Master写数据（复位后、START、STOP后）
; ; Bit 5 D_A: 数据地址标志
; ; 1 = 主机发送的是数据(Start后发过的第一个数据)
; ; 0 = 主机发送的是地址
; ; Bit 4 BF: 数据缓冲区满
; ; R_W = 0
; ; 1 = 从机接收到数据，未读
; ; 0 = 已读或未接受到数据
; ; R_W = 1
; ; 1 = 有数据待发送
; ; 0 = 数据已发送或正在发送
; ; Bit 3 NACK: Master读数据ACK
; ; 1 = Master停止接收数据
; ; 0 = Master继续接收下一个数据
; ; Bit 1 IICM: IIC 总线模式
; ; 1= 从机在未完成接收(未读 I2CBUF)时 HOLD 总线(拉低 I2C_SCL)
; ; 0= 从机在未完成接收不 HOLD 总线(高速 Master 可能会造成通讯紊乱)
; ; Bit 0 IICPINS: I2C总线脚位选择
; ; 1 = 选择B组总线(I2C_SCLB,I2C_SDAB)
; ; 0 = 选择A组总选(I2C_SCL_A,I2C_SDAA)

#define             I2CEN_ON             			B'10000000'		;//使能串行通讯功能
#define             I2CEN_OFF           			B'00000000'		;//屏蔽串行通讯功能
#define             Master_Read                		B'01000000'		;//Master读数据（主机发接收数据命令） 
#define             Master_Write               		B'00010000'		;//Master写数据（复位后、START、STOP后）
#define             D_A_send_data                   B'00100000'		;//主机发送的是数据(Start后发过的第一个数据)
#define             D_A_send_address                B'00000000'		;//主机发送的是地址
#define             BF_1                 			B'00010000' 
#define             BF_0                 			B'00000000'           
#define             NACK_1               		    B'00001000'		;//Master停止接收数据
#define             NACK_0                 			B'00000000'		;//Master继续接收下一个数据
#define             IICM_1                 			B'00000010'		;//从机在未完成接收(未读 I2CBUF)时 HOLD 总线(拉低 I2C_SCL)
#define             IICM_0                			B'00000000'		;//从机在未完成接收不 HOLD 总线(高速 Master 可能会造成通讯紊乱) 
#define             IICPINS_1                 		B'00000001'		;//选择B组总线(I2C_SCL_B,I2C_SDAB)		
#define             IICPINS_0            			B'00000000'		;//选择A组总选(I2C_SCL_A,I2C_SDAA) 


;*****************************************************************************
;========================   I2C  初始化   ====================================
;*****************************************************************************	
I2C_INIT:
;//1、IO端口设置  
		;//I2C_SCLA---------IOB0--------------------
		;//I2C_SDAA---------IOB1--------------------		
		BSET        PUB,0	;//0:上拉关闭 1:上拉使能
		BSET        PUB,1	;//0:上拉关闭 1:上拉使能
		BCLR		OEB,0	;//0:输入 1:输出
		BCLR		OEB,1	;//0:输入 1:输出

;//2、设置串行通讯功能
		MOVIA		IICPINS_0	;//选择A组总选(I2C_SCL_A,I2C_SDAA)
		MOVAR		I2CCON
		BSET		INTCR0,I2CEN		;//使能串行通讯功能
;//3、设置从机地址	
		;//I2ADR0,0
		;//表示主设备向从设备写数据，1表示主设备向从设备读数据	
		MOVIA		0xA0
		MOVAR       I2CADR
		
;//4、中断使能设置	
		BCLR		INTF0,I2CIF		;//清中断标志
        BSET		INTCR0,I2CIE
		CLRR		INTF0	
		BSET 		OPTION,GIE
		RETURN

;***********************************END OF FILE**********************************


