;*******************(C) COPYRIGHT 2019 Masses-Chip ******************************
;* File Name          : PWM1_Init.ASM
;* Author             : MASSES CHIP
;* Version            : V1.00
;* Date               : 2019/07/01
;;****************************************************************************
;
;PWM1初始化
;
;//****************************************************************************
;/////////////////////T0CR 控制寄存器各位定义//////////////////////////////////
;//****************************************************************************
;//TxCR 定时器控制寄存器
;//TCxEN:  TCx模块使能位
;//1 = 使能TCx
;//0 = 关闭TCx
;//TCxMOD:  TCx模式选择位
;//1 = 16位模式
;//0 = 8位模式
;//TCxCKS:  TCx时钟源选择
;//TCxCKS[1:0]	TCx时钟源选择
;//00	Foscl(低频系统时钟)
;//01	Fosch(高频系统时钟)
;//10	Fcpu
;//11	TC0:(T0cki) TC1:(TK)
;//TCxCKPS[2:0]:  TCx预分频比选择
;//TCxCKPS[2:0]	TCx预分频比
;//000	1:1
;//001	1:2
;//010	1:4
;//011	1:8
;//100	1:16
;//101	1:32
;//110	1:64
;//111	1:128
#DEFINE         TC1EN_0         	b'00000000'       ;//1 = 使能TCx
#DEFINE         TC1EN_1         	b'10000000'       ;//0 = 关闭TCx
#DEFINE         TC1MOD_8         	b'00000000'       ;//0 = 8位模式
#DEFINE         TC1MOD_16        	b'01000000'       ;//1 = 16位模式
#DEFINE         TC1CKS_Foscl     	b'00000000'       ;//Foscl(低频系统时钟)
#DEFINE         TC1CKS_Fosch     	b'00001000'       ;//Fosch(高频系统时钟)
#DEFINE         TC1CKS_Fcpu      	b'00010000'       ;//Fcpu
#DEFINE         TC1CKS_TC0CKI       b'00011000'       ;//T0CKI（TC0）/T1CKI （TC1）
#DEFINE         TC1CKPS_1_1      	b'00000000'       ;//1:1分频
#DEFINE         TC1CKPS_1_2      	b'00000001'       ;//1:2分频
#DEFINE         TC1CKPS_1_4      	b'00000010'       ;//1:4分频
#DEFINE         TC1CKPS_1_8     	b'00000011'       ;//1:8分频
#DEFINE         TC1CKPS_1_16     	b'00000100'       ;//1:16分频
#DEFINE         TC1CKPS_1_32     	b'00000101'       ;//1:32分频
#DEFINE         TC1CKPS_1_64     	b'00000110'       ;//1:64分频
#DEFINE         TC1CKPS_1_128    	b'00000111'       ;//1:128分频
;******************************************************************************************************
;/////////////////////PWM1CR控制寄存器各位定义////////////////////////////////////////////////////////
;******************************************************************************************************
;//Bit 7 PWM1EN: PWM1模块使能位
;//1 = 使能PWM1
;//0 = 关闭PWM1
;//Bit 6 PWM1POE: PWM1正相波形输出使能位
;//1 = 端口输出PWM1P波形
;//0 = 端口用作IO
;//Bit 5 PWM1NOE: PWM1反相波形输出使能位
;//1 = 端口输出PWM1N波形
;//0 = 端口用作IO
;//Bit 4 PWMxPAS: PWMxP波形有效电平选择
;//1 = PWMxP波形有效电平为低电平
;//0 = PWMxP波形有效电平为高电平
;//Bit 3 PWM1NAS: PWM1N波形有效电平选择
;//1 = 端口输出PWM波形高电平有效
;//0 = 端口输出PWM波形低电平有效
;//Bit 1 PWM1M: PWM1模式选择
;//1 = 单脉冲模式（需将定时器1设置成16位模式）
;//0 = 正常PWM模式（需将定时器1设置成8为模式）
;//Bit 0 PWM1T: PWM1触发事件设置
;//1 = T0CKI上升沿/下降沿
;//0 = T0CKI上升沿
#define		PWM1EN_1				b'10000000'       				;//使能PWM
#define   	PWM1EN_0     			b'00000000'        				;//关闭PWM
#define		PWM1POE_1				b'01000000'        				;//端口输出PWM1P波形
#define		PWM1POE_0				b'00000000'        				;//端口用作IO
#define		PWM1NOE_1				b'00100000'        				;//端口输出PWM1N波形
#define		PWM1NOE_0				b'00000000'        				;//端口用作IO
#define		PWM1PAS_1				b'00010000'        				;//PWM1P波形有效电平为低电平
#define		PWM1PAS_0				b'00000000'        				;//PWM1P波形有效电平为高电平
#define		PWM1NAS_1				b'00001000'        				;//PWM1N波形有效电平为高电平
#define		PWM1NAS_0				b'00000000'       				;//PWM1N波形有效电平为低电平
#define		PWM1M_1                 b'00000010'                     ;//单脉冲模式（需将定时器1设置成16位模式）
#define		PWM1M_0                 b'00000000'                     ;//正常PWM模式（需将定时器1设置成8为模式）
#define     PWM1T_1                 b'00000001'                     ;//T1CKI上升沿/下降沿
#define     PWM1T_0                 b'00000000'                     ;//T1CKI上升沿           
#define		PWM1S_000				b'00000000'						;//PWM无输出波形端口PWM1P/PWM1N
#define		PWM1S_001				b'00000001'						;//PWM输出波形端口PWM1PA/PWM1NA
#define		PWM1S_010				b'00000010'						;//PWM输出波形端口PWM1PB/PWM1NB
#define		PWM1S_011				b'00000011'						;//PWM输出波形端口PWM1P/PWM1N
#define		PWM1S_100				b'00000100'						;//PWM输出波形端口PWM1PC/PWM1NC
#define		PWM1S_101				b'00000101'						;//PWM输出波形端口PWM1P/PWM1N
#define		PWM1S_110				b'00000110'						;//PWM输出波形端口PWM1P/PWM1NO
#define		PWM1S_111				b'00000111'						;//PWM输出波形端口PWM1P/PWM1N
;******************************************************************************************************
;===========================================PWM1设置===================================================
;******************************************************************************************************
PWM1_Init:
;//1、IO端口设置
	    MOVIA        0x03                                           			;//PWM1NA/PWM1PA口输出PWM1波形
		MOVAR        OEA
;//2、时钟源设置(以TC1为例,使其产生1KHz的波形)		
		MOVIA        TC1MOD_8 + TC1CKS_Fosch + TC1CKPS_1_64        				;//各模式位的选择 
		MOVAR	     T1CR		               									;//将模式位配置字写入T1CR           
		CLRR	     TC1CH                     									;//将TC1CH清零
		MOVIA        249                      	 								;//将125写入A
		MOVAR	     TC1CL                     									;16M/64/(249+1)=1KHz 
;//3、PWM设置
		MOVIA	     PWM1POE_1+PWM1NOE_1+PWM1PAS_1+PWM1NAS_1+PWM1M_0+PWM1T_0	;//PWM时基选择定时器T1
		MOVAR	     PWM1CR                    									;//PWM1使能,端口输出波形
		MOVIA        PWM1S_001                 									;//PWM1PA/PWM1NA 用作PWM输出
		MOVAR        PWM1S 
		MOVIA		 0
		MOVAR		 PWM1DL                     								;//低位清零
		MOVIA	     (249+1)/2                  								;//产生占空比为50%的PWM波形      
		MOVAR	     PWM1DH              
;//4、开启PWM1
        BSET         T1CR,7					    								;//定时器T1开启
		BSET         PWM1CR,7													;//PWM1开启
		RETURN